# flashinfer_bench.apply

`flashinfer_bench.apply` provides a tool that meets two needs:

1. **Apply** best-performing one from FlashInfer Trace database to the LLM engine
2. **Trace** the kernel in the LLM engine and dump its input as FlashInfer Trace's workload format

```{eval-rst}
.. currentmodule:: flashinfer_bench

.. autofunction:: apply

.. autofunction:: enable_apply

.. autofunction:: disable_apply
```
